@@ -20,6 +20,7 @@
 #define COLUMN_CODEC @"Codec"
 #define COLUMN_FILESIZE @"Filesize"
 #define COLUMN_YEAR @"Year"
+#define COLUMN_RATING @"Rating"
 
 @implementation DuplicateItemsTab
 
@@ -58,6 +59,8 @@
 		return [track filesizeString];
 	else if ([ident isEqual:COLUMN_YEAR])
 		return [NSString stringWithFormat:@"%d", [track year]];
+  else if ([ident isEqual:COLUMN_RATING])
+    return [NSNumber numberWithUnsignedInt:[track rating]];
 	else
 	{
 		NSLog(@"Invalid column tag in DuplicateItemsTab");
@@ -391,7 +394,7 @@
 - (void)deleteFromNJB
 {
 	int result = NSRunAlertPanel(NSLocalizedString(@"File Deletion", nil),
-															 NSLocalizedString(@"Are you sure you want to delete the selected items off the NJB?", nil),
+															 NSLocalizedString(@"Are you sure you want to delete the selected items off the device?", nil),
 															 NSLocalizedString(@"No", nil),
 															 NSLocalizedString(@"Yes", nil), nil);
 	if (result == NSAlertDefaultReturn)
