@@ -37,7 +37,7 @@
 - (void)awakeFromNib
 {
 	[super awakeFromNib];
-	browser = [[FileSystemBrowser alloc] initWithBrowser:fileBrowser atLocation:[self browserPathFromPreferences] withAllowedExtensions:[self allowedExtensions]];
+	browser = [[FileSystemBrowser alloc] initWithBrowser:fileBrowser atLocation:[self browserPathFromPreferences]];
 	[browser setTarget:self];
 	[browser setFileAction:@selector(fileSystemBrowserFileClick:)];
 	[browser setDirectoryAction:@selector(fileSystemBrowserDirectoryClick:)];
@@ -409,10 +409,4 @@
  */
 - (NSString *)browserPathFromPreferences{ return @"/"; }
 
-/*
- * return the extensions allowed to be selected
- * default: all allowed (return nil)
- */
-- (NSArray *)allowedExtensions{ return nil; }
-
 @end
