@@ -17,9 +17,6 @@
 
 #include <dirent.h>
 
-#include <CoreFoundation/CoreFoundation.h>
-//#include <CFByteOrder.h>
-
 /*
  * USB spec information
  *
@@ -35,6 +32,7 @@
 #define USB_CLASS_COMM			2
 #define USB_CLASS_HID			3
 #define USB_CLASS_PRINTER		7
+#define USB_CLASS_PTP			6
 #define USB_CLASS_MASS_STORAGE		8
 #define USB_CLASS_HUB			9
 #define USB_CLASS_DATA			10
@@ -225,12 +223,12 @@ struct usb_ctrl_setup {
  * This is supposed to look weird. This file is generated from autoconf
  * and I didn't want to make this too complicated.
  */
-/*#if 1
+/* Modified by Richard Low to allow universal binary compilation */
+#ifdef __BIG_ENDIAN__
 #define USB_LE16_TO_CPU(x) do { x = ((x & 0xff) << 8) | ((x & 0xff00) >> 8); } while(0)
 #else
 #define USB_LE16_TO_CPU(x)
-#endif*/
-#define USB_LE16_TO_CPU(x) x = CFSwapInt16LittleToHost(x);
+#endif
 
 /* Data types */
 struct usb_device;
